# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class FlowConfigMetaData(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        FlowConfigMetaData - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'config_state': 'str',
            'flow_type': 'str',
            'locked_by_user': 'User',
            'newest_published_version': 'str',
            'newest_version': 'str',
            'associated_workspaces': 'list[Workspace]',
            'description': 'str',
            'has_draft': 'bool',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'config_state': 'configState',
            'flow_type': 'flowType',
            'locked_by_user': 'lockedByUser',
            'newest_published_version': 'newestPublishedVersion',
            'newest_version': 'newestVersion',
            'associated_workspaces': 'associatedWorkspaces',
            'description': 'description',
            'has_draft': 'hasDraft',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._config_state = None
        self._flow_type = None
        self._locked_by_user = None
        self._newest_published_version = None
        self._newest_version = None
        self._associated_workspaces = None
        self._description = None
        self._has_draft = False
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this FlowConfigMetaData.
        The globally unique identifier for the object.

        :return: The id of this FlowConfigMetaData.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this FlowConfigMetaData.
        The globally unique identifier for the object.

        :param id: The id of this FlowConfigMetaData.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this FlowConfigMetaData.


        :return: The name of this FlowConfigMetaData.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this FlowConfigMetaData.


        :param name: The name of this FlowConfigMetaData.
        :type: str
        """
        self._name = name

    @property
    def config_state(self):
        """
        Gets the config_state of this FlowConfigMetaData.
        Usability of this flow definition. (output only)

        :return: The config_state of this FlowConfigMetaData.
        :rtype: str
        """
        return self._config_state

    @config_state.setter
    def config_state(self, config_state):
        """
        Sets the config_state of this FlowConfigMetaData.
        Usability of this flow definition. (output only)

        :param config_state: The config_state of this FlowConfigMetaData.
        :type: str
        """
        allowed_values = ["UNKNOWN", "ACTIVE", "INACTIVE", "DELETED"]
        if config_state not in allowed_values:
            raise ValueError(
                "Invalid value for `config_state`, must be one of {0}"
                .format(allowed_values)
            )
        self._config_state = config_state

    @property
    def flow_type(self):
        """
        Gets the flow_type of this FlowConfigMetaData.
        Type of flow this definition describes

        :return: The flow_type of this FlowConfigMetaData.
        :rtype: str
        """
        return self._flow_type

    @flow_type.setter
    def flow_type(self, flow_type):
        """
        Sets the flow_type of this FlowConfigMetaData.
        Type of flow this definition describes

        :param flow_type: The flow_type of this FlowConfigMetaData.
        :type: str
        """
        allowed_values = ["UNKNOWN", "WORKFLOW"]
        if flow_type not in allowed_values:
            raise ValueError(
                "Invalid value for `flow_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._flow_type = flow_type

    @property
    def locked_by_user(self):
        """
        Gets the locked_by_user of this FlowConfigMetaData.
        If locked for editing, the user who locked this definition, otherwise null

        :return: The locked_by_user of this FlowConfigMetaData.
        :rtype: User
        """
        return self._locked_by_user

    @locked_by_user.setter
    def locked_by_user(self, locked_by_user):
        """
        Sets the locked_by_user of this FlowConfigMetaData.
        If locked for editing, the user who locked this definition, otherwise null

        :param locked_by_user: The locked_by_user of this FlowConfigMetaData.
        :type: User
        """
        self._locked_by_user = locked_by_user

    @property
    def newest_published_version(self):
        """
        Gets the newest_published_version of this FlowConfigMetaData.
        The most recently published version (output only)

        :return: The newest_published_version of this FlowConfigMetaData.
        :rtype: str
        """
        return self._newest_published_version

    @newest_published_version.setter
    def newest_published_version(self, newest_published_version):
        """
        Sets the newest_published_version of this FlowConfigMetaData.
        The most recently published version (output only)

        :param newest_published_version: The newest_published_version of this FlowConfigMetaData.
        :type: str
        """
        self._newest_published_version = newest_published_version

    @property
    def newest_version(self):
        """
        Gets the newest_version of this FlowConfigMetaData.
        The most recent version, regardless of published state (output only)

        :return: The newest_version of this FlowConfigMetaData.
        :rtype: str
        """
        return self._newest_version

    @newest_version.setter
    def newest_version(self, newest_version):
        """
        Sets the newest_version of this FlowConfigMetaData.
        The most recent version, regardless of published state (output only)

        :param newest_version: The newest_version of this FlowConfigMetaData.
        :type: str
        """
        self._newest_version = newest_version

    @property
    def associated_workspaces(self):
        """
        Gets the associated_workspaces of this FlowConfigMetaData.
        Workspaces associated with this flow.

        :return: The associated_workspaces of this FlowConfigMetaData.
        :rtype: list[Workspace]
        """
        return self._associated_workspaces

    @associated_workspaces.setter
    def associated_workspaces(self, associated_workspaces):
        """
        Sets the associated_workspaces of this FlowConfigMetaData.
        Workspaces associated with this flow.

        :param associated_workspaces: The associated_workspaces of this FlowConfigMetaData.
        :type: list[Workspace]
        """
        self._associated_workspaces = associated_workspaces

    @property
    def description(self):
        """
        Gets the description of this FlowConfigMetaData.
        User notes describing the flow definition.

        :return: The description of this FlowConfigMetaData.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this FlowConfigMetaData.
        User notes describing the flow definition.

        :param description: The description of this FlowConfigMetaData.
        :type: str
        """
        self._description = description

    @property
    def has_draft(self):
        """
        Gets the has_draft of this FlowConfigMetaData.
        Flag if this definition has a draft populated.

        :return: The has_draft of this FlowConfigMetaData.
        :rtype: bool
        """
        return self._has_draft

    @has_draft.setter
    def has_draft(self, has_draft):
        """
        Sets the has_draft of this FlowConfigMetaData.
        Flag if this definition has a draft populated.

        :param has_draft: The has_draft of this FlowConfigMetaData.
        :type: bool
        """
        self._has_draft = has_draft

    @property
    def self_uri(self):
        """
        Gets the self_uri of this FlowConfigMetaData.
        The URI for this object

        :return: The self_uri of this FlowConfigMetaData.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this FlowConfigMetaData.
        The URI for this object

        :param self_uri: The self_uri of this FlowConfigMetaData.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class VoiceRateUpdate(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        VoiceRateUpdate - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'currency': 'str',
            'inbound_toll_free': 'VoiceRate',
            'extended': 'list[VoiceRateExtended]',
            'inbound_tolled': 'VoiceRate',
            'outbound_local': 'VoiceRate',
            'outbound_intra_state': 'VoiceRate',
            'outbound_inter_state': 'VoiceRate',
            'outbound_international': 'list[VoiceRateInternational]',
            'amendment_date': 'datetime',
            'effective_date': 'datetime',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'currency': 'currency',
            'inbound_toll_free': 'inboundTollFree',
            'extended': 'extended',
            'inbound_tolled': 'inboundTolled',
            'outbound_local': 'outboundLocal',
            'outbound_intra_state': 'outboundIntraState',
            'outbound_inter_state': 'outboundInterState',
            'outbound_international': 'outboundInternational',
            'amendment_date': 'amendmentDate',
            'effective_date': 'effectiveDate',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._currency = None
        self._inbound_toll_free = None
        self._extended = None
        self._inbound_tolled = None
        self._outbound_local = None
        self._outbound_intra_state = None
        self._outbound_inter_state = None
        self._outbound_international = None
        self._amendment_date = None
        self._effective_date = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this VoiceRateUpdate.
        The globally unique identifier for the object.

        :return: The id of this VoiceRateUpdate.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this VoiceRateUpdate.
        The globally unique identifier for the object.

        :param id: The id of this VoiceRateUpdate.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this VoiceRateUpdate.


        :return: The name of this VoiceRateUpdate.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this VoiceRateUpdate.


        :param name: The name of this VoiceRateUpdate.
        :type: str
        """
        self._name = name

    @property
    def currency(self):
        """
        Gets the currency of this VoiceRateUpdate.
        The ISO 4217 currency code of the voice rate.

        :return: The currency of this VoiceRateUpdate.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """
        Sets the currency of this VoiceRateUpdate.
        The ISO 4217 currency code of the voice rate.

        :param currency: The currency of this VoiceRateUpdate.
        :type: str
        """
        self._currency = currency

    @property
    def inbound_toll_free(self):
        """
        Gets the inbound_toll_free of this VoiceRateUpdate.
        The inbound toll free rate.

        :return: The inbound_toll_free of this VoiceRateUpdate.
        :rtype: VoiceRate
        """
        return self._inbound_toll_free

    @inbound_toll_free.setter
    def inbound_toll_free(self, inbound_toll_free):
        """
        Sets the inbound_toll_free of this VoiceRateUpdate.
        The inbound toll free rate.

        :param inbound_toll_free: The inbound_toll_free of this VoiceRateUpdate.
        :type: VoiceRate
        """
        self._inbound_toll_free = inbound_toll_free

    @property
    def extended(self):
        """
        Gets the extended of this VoiceRateUpdate.
        The domestic extended rates.

        :return: The extended of this VoiceRateUpdate.
        :rtype: list[VoiceRateExtended]
        """
        return self._extended

    @extended.setter
    def extended(self, extended):
        """
        Sets the extended of this VoiceRateUpdate.
        The domestic extended rates.

        :param extended: The extended of this VoiceRateUpdate.
        :type: list[VoiceRateExtended]
        """
        self._extended = extended

    @property
    def inbound_tolled(self):
        """
        Gets the inbound_tolled of this VoiceRateUpdate.
        The inbound tolled rate.

        :return: The inbound_tolled of this VoiceRateUpdate.
        :rtype: VoiceRate
        """
        return self._inbound_tolled

    @inbound_tolled.setter
    def inbound_tolled(self, inbound_tolled):
        """
        Sets the inbound_tolled of this VoiceRateUpdate.
        The inbound tolled rate.

        :param inbound_tolled: The inbound_tolled of this VoiceRateUpdate.
        :type: VoiceRate
        """
        self._inbound_tolled = inbound_tolled

    @property
    def outbound_local(self):
        """
        Gets the outbound_local of this VoiceRateUpdate.
        The outbound local rate.

        :return: The outbound_local of this VoiceRateUpdate.
        :rtype: VoiceRate
        """
        return self._outbound_local

    @outbound_local.setter
    def outbound_local(self, outbound_local):
        """
        Sets the outbound_local of this VoiceRateUpdate.
        The outbound local rate.

        :param outbound_local: The outbound_local of this VoiceRateUpdate.
        :type: VoiceRate
        """
        self._outbound_local = outbound_local

    @property
    def outbound_intra_state(self):
        """
        Gets the outbound_intra_state of this VoiceRateUpdate.
        The outbound intra-state rate.

        :return: The outbound_intra_state of this VoiceRateUpdate.
        :rtype: VoiceRate
        """
        return self._outbound_intra_state

    @outbound_intra_state.setter
    def outbound_intra_state(self, outbound_intra_state):
        """
        Sets the outbound_intra_state of this VoiceRateUpdate.
        The outbound intra-state rate.

        :param outbound_intra_state: The outbound_intra_state of this VoiceRateUpdate.
        :type: VoiceRate
        """
        self._outbound_intra_state = outbound_intra_state

    @property
    def outbound_inter_state(self):
        """
        Gets the outbound_inter_state of this VoiceRateUpdate.
        The outbound inter-state rate.

        :return: The outbound_inter_state of this VoiceRateUpdate.
        :rtype: VoiceRate
        """
        return self._outbound_inter_state

    @outbound_inter_state.setter
    def outbound_inter_state(self, outbound_inter_state):
        """
        Sets the outbound_inter_state of this VoiceRateUpdate.
        The outbound inter-state rate.

        :param outbound_inter_state: The outbound_inter_state of this VoiceRateUpdate.
        :type: VoiceRate
        """
        self._outbound_inter_state = outbound_inter_state

    @property
    def outbound_international(self):
        """
        Gets the outbound_international of this VoiceRateUpdate.
        The outbound international rates.

        :return: The outbound_international of this VoiceRateUpdate.
        :rtype: list[VoiceRateInternational]
        """
        return self._outbound_international

    @outbound_international.setter
    def outbound_international(self, outbound_international):
        """
        Sets the outbound_international of this VoiceRateUpdate.
        The outbound international rates.

        :param outbound_international: The outbound_international of this VoiceRateUpdate.
        :type: list[VoiceRateInternational]
        """
        self._outbound_international = outbound_international

    @property
    def amendment_date(self):
        """
        Gets the amendment_date of this VoiceRateUpdate.
        The date of the rate amendment. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The amendment_date of this VoiceRateUpdate.
        :rtype: datetime
        """
        return self._amendment_date

    @amendment_date.setter
    def amendment_date(self, amendment_date):
        """
        Sets the amendment_date of this VoiceRateUpdate.
        The date of the rate amendment. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param amendment_date: The amendment_date of this VoiceRateUpdate.
        :type: datetime
        """
        self._amendment_date = amendment_date

    @property
    def effective_date(self):
        """
        Gets the effective_date of this VoiceRateUpdate.
        The effective date of the rate amendment. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The effective_date of this VoiceRateUpdate.
        :rtype: datetime
        """
        return self._effective_date

    @effective_date.setter
    def effective_date(self, effective_date):
        """
        Sets the effective_date of this VoiceRateUpdate.
        The effective date of the rate amendment. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param effective_date: The effective_date of this VoiceRateUpdate.
        :type: datetime
        """
        self._effective_date = effective_date

    @property
    def self_uri(self):
        """
        Gets the self_uri of this VoiceRateUpdate.
        The URI for this object

        :return: The self_uri of this VoiceRateUpdate.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this VoiceRateUpdate.
        The URI for this object

        :param self_uri: The self_uri of this VoiceRateUpdate.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class IVR(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        IVR - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'version': 'int',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'modified_by': 'str',
            'created_by': 'str',
            'state': 'str',
            'modified_by_app': 'str',
            'created_by_app': 'str',
            'ivr_uri': 'str',
            'dnis': 'list[str]',
            'flow_id': 'str',
            'schedule_id': 'str',
            'open_hours_flow': 'UriReference',
            'closed_hours_flow': 'UriReference',
            'schedule_group': 'UriReference',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'version': 'version',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'modified_by': 'modifiedBy',
            'created_by': 'createdBy',
            'state': 'state',
            'modified_by_app': 'modifiedByApp',
            'created_by_app': 'createdByApp',
            'ivr_uri': 'ivrUri',
            'dnis': 'dnis',
            'flow_id': 'flowId',
            'schedule_id': 'scheduleId',
            'open_hours_flow': 'openHoursFlow',
            'closed_hours_flow': 'closedHoursFlow',
            'schedule_group': 'scheduleGroup',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._version = None
        self._date_created = None
        self._date_modified = None
        self._modified_by = None
        self._created_by = None
        self._state = None
        self._modified_by_app = None
        self._created_by_app = None
        self._ivr_uri = None
        self._dnis = None
        self._flow_id = None
        self._schedule_id = None
        self._open_hours_flow = None
        self._closed_hours_flow = None
        self._schedule_group = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this IVR.
        The globally unique identifier for the object.

        :return: The id of this IVR.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this IVR.
        The globally unique identifier for the object.

        :param id: The id of this IVR.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this IVR.


        :return: The name of this IVR.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this IVR.


        :param name: The name of this IVR.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this IVR.


        :return: The description of this IVR.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this IVR.


        :param description: The description of this IVR.
        :type: str
        """
        self._description = description

    @property
    def version(self):
        """
        Gets the version of this IVR.


        :return: The version of this IVR.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this IVR.


        :param version: The version of this IVR.
        :type: int
        """
        self._version = version

    @property
    def date_created(self):
        """
        Gets the date_created of this IVR.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_created of this IVR.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this IVR.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_created: The date_created of this IVR.
        :type: datetime
        """
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this IVR.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this IVR.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this IVR.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this IVR.
        :type: datetime
        """
        self._date_modified = date_modified

    @property
    def modified_by(self):
        """
        Gets the modified_by of this IVR.


        :return: The modified_by of this IVR.
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this IVR.


        :param modified_by: The modified_by of this IVR.
        :type: str
        """
        self._modified_by = modified_by

    @property
    def created_by(self):
        """
        Gets the created_by of this IVR.


        :return: The created_by of this IVR.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this IVR.


        :param created_by: The created_by of this IVR.
        :type: str
        """
        self._created_by = created_by

    @property
    def state(self):
        """
        Gets the state of this IVR.


        :return: The state of this IVR.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this IVR.


        :param state: The state of this IVR.
        :type: str
        """
        allowed_values = ["active", "inactive", "deleted"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )
        self._state = state

    @property
    def modified_by_app(self):
        """
        Gets the modified_by_app of this IVR.


        :return: The modified_by_app of this IVR.
        :rtype: str
        """
        return self._modified_by_app

    @modified_by_app.setter
    def modified_by_app(self, modified_by_app):
        """
        Sets the modified_by_app of this IVR.


        :param modified_by_app: The modified_by_app of this IVR.
        :type: str
        """
        self._modified_by_app = modified_by_app

    @property
    def created_by_app(self):
        """
        Gets the created_by_app of this IVR.


        :return: The created_by_app of this IVR.
        :rtype: str
        """
        return self._created_by_app

    @created_by_app.setter
    def created_by_app(self, created_by_app):
        """
        Sets the created_by_app of this IVR.


        :param created_by_app: The created_by_app of this IVR.
        :type: str
        """
        self._created_by_app = created_by_app

    @property
    def ivr_uri(self):
        """
        Gets the ivr_uri of this IVR.


        :return: The ivr_uri of this IVR.
        :rtype: str
        """
        return self._ivr_uri

    @ivr_uri.setter
    def ivr_uri(self, ivr_uri):
        """
        Sets the ivr_uri of this IVR.


        :param ivr_uri: The ivr_uri of this IVR.
        :type: str
        """
        self._ivr_uri = ivr_uri

    @property
    def dnis(self):
        """
        Gets the dnis of this IVR.


        :return: The dnis of this IVR.
        :rtype: list[str]
        """
        return self._dnis

    @dnis.setter
    def dnis(self, dnis):
        """
        Sets the dnis of this IVR.


        :param dnis: The dnis of this IVR.
        :type: list[str]
        """
        self._dnis = dnis

    @property
    def flow_id(self):
        """
        Gets the flow_id of this IVR.


        :return: The flow_id of this IVR.
        :rtype: str
        """
        return self._flow_id

    @flow_id.setter
    def flow_id(self, flow_id):
        """
        Sets the flow_id of this IVR.


        :param flow_id: The flow_id of this IVR.
        :type: str
        """
        self._flow_id = flow_id

    @property
    def schedule_id(self):
        """
        Gets the schedule_id of this IVR.


        :return: The schedule_id of this IVR.
        :rtype: str
        """
        return self._schedule_id

    @schedule_id.setter
    def schedule_id(self, schedule_id):
        """
        Sets the schedule_id of this IVR.


        :param schedule_id: The schedule_id of this IVR.
        :type: str
        """
        self._schedule_id = schedule_id

    @property
    def open_hours_flow(self):
        """
        Gets the open_hours_flow of this IVR.


        :return: The open_hours_flow of this IVR.
        :rtype: UriReference
        """
        return self._open_hours_flow

    @open_hours_flow.setter
    def open_hours_flow(self, open_hours_flow):
        """
        Sets the open_hours_flow of this IVR.


        :param open_hours_flow: The open_hours_flow of this IVR.
        :type: UriReference
        """
        self._open_hours_flow = open_hours_flow

    @property
    def closed_hours_flow(self):
        """
        Gets the closed_hours_flow of this IVR.


        :return: The closed_hours_flow of this IVR.
        :rtype: UriReference
        """
        return self._closed_hours_flow

    @closed_hours_flow.setter
    def closed_hours_flow(self, closed_hours_flow):
        """
        Sets the closed_hours_flow of this IVR.


        :param closed_hours_flow: The closed_hours_flow of this IVR.
        :type: UriReference
        """
        self._closed_hours_flow = closed_hours_flow

    @property
    def schedule_group(self):
        """
        Gets the schedule_group of this IVR.


        :return: The schedule_group of this IVR.
        :rtype: UriReference
        """
        return self._schedule_group

    @schedule_group.setter
    def schedule_group(self, schedule_group):
        """
        Sets the schedule_group of this IVR.


        :param schedule_group: The schedule_group of this IVR.
        :type: UriReference
        """
        self._schedule_group = schedule_group

    @property
    def self_uri(self):
        """
        Gets the self_uri of this IVR.
        The URI for this object

        :return: The self_uri of this IVR.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this IVR.
        The URI for this object

        :param self_uri: The self_uri of this IVR.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class FlowDetails(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        FlowDetails - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'flow_config_id': 'FlowConfigId',
            'launch_time': 'datetime',
            'launch_type': 'str',
            'launched_by': 'User',
            'status': 'str',
            'associated_documents': 'list[AssociatedDocument]',
            'flow_completion_time': 'datetime',
            'flow_completion_reason': 'str',
            'flow_error_info': 'ErrorBody',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'flow_config_id': 'flowConfigId',
            'launch_time': 'launchTime',
            'launch_type': 'launchType',
            'launched_by': 'launchedBy',
            'status': 'status',
            'associated_documents': 'associatedDocuments',
            'flow_completion_time': 'flowCompletionTime',
            'flow_completion_reason': 'flowCompletionReason',
            'flow_error_info': 'flowErrorInfo',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._flow_config_id = None
        self._launch_time = None
        self._launch_type = None
        self._launched_by = None
        self._status = None
        self._associated_documents = None
        self._flow_completion_time = None
        self._flow_completion_reason = None
        self._flow_error_info = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this FlowDetails.
        The globally unique identifier for the object.

        :return: The id of this FlowDetails.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this FlowDetails.
        The globally unique identifier for the object.

        :param id: The id of this FlowDetails.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this FlowDetails.


        :return: The name of this FlowDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this FlowDetails.


        :param name: The name of this FlowDetails.
        :type: str
        """
        self._name = name

    @property
    def flow_config_id(self):
        """
        Gets the flow_config_id of this FlowDetails.
        The FlowConfigId that was used to launch this flow.

        :return: The flow_config_id of this FlowDetails.
        :rtype: FlowConfigId
        """
        return self._flow_config_id

    @flow_config_id.setter
    def flow_config_id(self, flow_config_id):
        """
        Sets the flow_config_id of this FlowDetails.
        The FlowConfigId that was used to launch this flow.

        :param flow_config_id: The flow_config_id of this FlowDetails.
        :type: FlowConfigId
        """
        self._flow_config_id = flow_config_id

    @property
    def launch_time(self):
        """
        Gets the launch_time of this FlowDetails.
        The time the flow was launched. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The launch_time of this FlowDetails.
        :rtype: datetime
        """
        return self._launch_time

    @launch_time.setter
    def launch_time(self, launch_time):
        """
        Sets the launch_time of this FlowDetails.
        The time the flow was launched. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param launch_time: The launch_time of this FlowDetails.
        :type: datetime
        """
        self._launch_time = launch_time

    @property
    def launch_type(self):
        """
        Gets the launch_type of this FlowDetails.
        The launch mode for this flow instance.

        :return: The launch_type of this FlowDetails.
        :rtype: str
        """
        return self._launch_type

    @launch_type.setter
    def launch_type(self, launch_type):
        """
        Sets the launch_type of this FlowDetails.
        The launch mode for this flow instance.

        :param launch_type: The launch_type of this FlowDetails.
        :type: str
        """
        allowed_values = ["UNKNOWN", "NORMAL", "TEST", "AUTOMATIC"]
        if launch_type not in allowed_values:
            raise ValueError(
                "Invalid value for `launch_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._launch_type = launch_type

    @property
    def launched_by(self):
        """
        Gets the launched_by of this FlowDetails.
        The user who launched the flow, if the flow was launched as the result of that user's action.

        :return: The launched_by of this FlowDetails.
        :rtype: User
        """
        return self._launched_by

    @launched_by.setter
    def launched_by(self, launched_by):
        """
        Sets the launched_by of this FlowDetails.
        The user who launched the flow, if the flow was launched as the result of that user's action.

        :param launched_by: The launched_by of this FlowDetails.
        :type: User
        """
        self._launched_by = launched_by

    @property
    def status(self):
        """
        Gets the status of this FlowDetails.
        The flow's running status, which indicates whether the flow is running normally or completed, etc.

        :return: The status of this FlowDetails.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this FlowDetails.
        The flow's running status, which indicates whether the flow is running normally or completed, etc.

        :param status: The status of this FlowDetails.
        :type: str
        """
        allowed_values = ["UNKNOWN", "RUNNING", "ERROR", "TERMINATED", "COMPLETED"]
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status`, must be one of {0}"
                .format(allowed_values)
            )
        self._status = status

    @property
    def associated_documents(self):
        """
        Gets the associated_documents of this FlowDetails.
        The documents associated with this flow.

        :return: The associated_documents of this FlowDetails.
        :rtype: list[AssociatedDocument]
        """
        return self._associated_documents

    @associated_documents.setter
    def associated_documents(self, associated_documents):
        """
        Sets the associated_documents of this FlowDetails.
        The documents associated with this flow.

        :param associated_documents: The associated_documents of this FlowDetails.
        :type: list[AssociatedDocument]
        """
        self._associated_documents = associated_documents

    @property
    def flow_completion_time(self):
        """
        Gets the flow_completion_time of this FlowDetails.
        The time the flow completed, if applicable. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The flow_completion_time of this FlowDetails.
        :rtype: datetime
        """
        return self._flow_completion_time

    @flow_completion_time.setter
    def flow_completion_time(self, flow_completion_time):
        """
        Sets the flow_completion_time of this FlowDetails.
        The time the flow completed, if applicable. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param flow_completion_time: The flow_completion_time of this FlowDetails.
        :type: datetime
        """
        self._flow_completion_time = flow_completion_time

    @property
    def flow_completion_reason(self):
        """
        Gets the flow_completion_reason of this FlowDetails.
        The completion reason set at the flow completion time, if applicable.

        :return: The flow_completion_reason of this FlowDetails.
        :rtype: str
        """
        return self._flow_completion_reason

    @flow_completion_reason.setter
    def flow_completion_reason(self, flow_completion_reason):
        """
        Sets the flow_completion_reason of this FlowDetails.
        The completion reason set at the flow completion time, if applicable.

        :param flow_completion_reason: The flow_completion_reason of this FlowDetails.
        :type: str
        """
        self._flow_completion_reason = flow_completion_reason

    @property
    def flow_error_info(self):
        """
        Gets the flow_error_info of this FlowDetails.
        Additional information if the flow is in error

        :return: The flow_error_info of this FlowDetails.
        :rtype: ErrorBody
        """
        return self._flow_error_info

    @flow_error_info.setter
    def flow_error_info(self, flow_error_info):
        """
        Sets the flow_error_info of this FlowDetails.
        Additional information if the flow is in error

        :param flow_error_info: The flow_error_info of this FlowDetails.
        :type: ErrorBody
        """
        self._flow_error_info = flow_error_info

    @property
    def self_uri(self):
        """
        Gets the self_uri of this FlowDetails.
        The URI for this object

        :return: The self_uri of this FlowDetails.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this FlowDetails.
        The URI for this object

        :param self_uri: The self_uri of this FlowDetails.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class ContactSales(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ContactSales - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'email': 'str',
            'first_name': 'str',
            'last_name': 'str',
            'contact_phone': 'str',
            'country': 'str',
            'title': 'str',
            'message': 'str',
            'language': 'str',
            'product_name': 'str',
            'quote_id': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'email': 'email',
            'first_name': 'firstName',
            'last_name': 'lastName',
            'contact_phone': 'contactPhone',
            'country': 'country',
            'title': 'title',
            'message': 'message',
            'language': 'language',
            'product_name': 'productName',
            'quote_id': 'quoteId',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._email = None
        self._first_name = None
        self._last_name = None
        self._contact_phone = None
        self._country = None
        self._title = None
        self._message = None
        self._language = None
        self._product_name = None
        self._quote_id = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this ContactSales.
        The globally unique identifier for the object.

        :return: The id of this ContactSales.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ContactSales.
        The globally unique identifier for the object.

        :param id: The id of this ContactSales.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ContactSales.


        :return: The name of this ContactSales.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ContactSales.


        :param name: The name of this ContactSales.
        :type: str
        """
        self._name = name

    @property
    def email(self):
        """
        Gets the email of this ContactSales.


        :return: The email of this ContactSales.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this ContactSales.


        :param email: The email of this ContactSales.
        :type: str
        """
        self._email = email

    @property
    def first_name(self):
        """
        Gets the first_name of this ContactSales.


        :return: The first_name of this ContactSales.
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """
        Sets the first_name of this ContactSales.


        :param first_name: The first_name of this ContactSales.
        :type: str
        """
        self._first_name = first_name

    @property
    def last_name(self):
        """
        Gets the last_name of this ContactSales.


        :return: The last_name of this ContactSales.
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """
        Sets the last_name of this ContactSales.


        :param last_name: The last_name of this ContactSales.
        :type: str
        """
        self._last_name = last_name

    @property
    def contact_phone(self):
        """
        Gets the contact_phone of this ContactSales.


        :return: The contact_phone of this ContactSales.
        :rtype: str
        """
        return self._contact_phone

    @contact_phone.setter
    def contact_phone(self, contact_phone):
        """
        Sets the contact_phone of this ContactSales.


        :param contact_phone: The contact_phone of this ContactSales.
        :type: str
        """
        self._contact_phone = contact_phone

    @property
    def country(self):
        """
        Gets the country of this ContactSales.


        :return: The country of this ContactSales.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this ContactSales.


        :param country: The country of this ContactSales.
        :type: str
        """
        self._country = country

    @property
    def title(self):
        """
        Gets the title of this ContactSales.


        :return: The title of this ContactSales.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this ContactSales.


        :param title: The title of this ContactSales.
        :type: str
        """
        self._title = title

    @property
    def message(self):
        """
        Gets the message of this ContactSales.


        :return: The message of this ContactSales.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this ContactSales.


        :param message: The message of this ContactSales.
        :type: str
        """
        self._message = message

    @property
    def language(self):
        """
        Gets the language of this ContactSales.


        :return: The language of this ContactSales.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """
        Sets the language of this ContactSales.


        :param language: The language of this ContactSales.
        :type: str
        """
        self._language = language

    @property
    def product_name(self):
        """
        Gets the product_name of this ContactSales.


        :return: The product_name of this ContactSales.
        :rtype: str
        """
        return self._product_name

    @product_name.setter
    def product_name(self, product_name):
        """
        Sets the product_name of this ContactSales.


        :param product_name: The product_name of this ContactSales.
        :type: str
        """
        self._product_name = product_name

    @property
    def quote_id(self):
        """
        Gets the quote_id of this ContactSales.


        :return: The quote_id of this ContactSales.
        :rtype: str
        """
        return self._quote_id

    @quote_id.setter
    def quote_id(self, quote_id):
        """
        Sets the quote_id of this ContactSales.


        :param quote_id: The quote_id of this ContactSales.
        :type: str
        """
        self._quote_id = quote_id

    @property
    def self_uri(self):
        """
        Gets the self_uri of this ContactSales.
        The URI for this object

        :return: The self_uri of this ContactSales.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this ContactSales.
        The URI for this object

        :param self_uri: The self_uri of this ContactSales.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class FacetStatistics(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        FacetStatistics - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'count': 'int',
            'min': 'float',
            'max': 'float',
            'mean': 'float',
            'std_deviation': 'float',
            'date_min': 'datetime',
            'date_max': 'datetime'
        }

        self.attribute_map = {
            'count': 'count',
            'min': 'min',
            'max': 'max',
            'mean': 'mean',
            'std_deviation': 'stdDeviation',
            'date_min': 'dateMin',
            'date_max': 'dateMax'
        }

        self._count = None
        self._min = None
        self._max = None
        self._mean = None
        self._std_deviation = None
        self._date_min = None
        self._date_max = None

    @property
    def count(self):
        """
        Gets the count of this FacetStatistics.


        :return: The count of this FacetStatistics.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this FacetStatistics.


        :param count: The count of this FacetStatistics.
        :type: int
        """
        self._count = count

    @property
    def min(self):
        """
        Gets the min of this FacetStatistics.


        :return: The min of this FacetStatistics.
        :rtype: float
        """
        return self._min

    @min.setter
    def min(self, min):
        """
        Sets the min of this FacetStatistics.


        :param min: The min of this FacetStatistics.
        :type: float
        """
        self._min = min

    @property
    def max(self):
        """
        Gets the max of this FacetStatistics.


        :return: The max of this FacetStatistics.
        :rtype: float
        """
        return self._max

    @max.setter
    def max(self, max):
        """
        Sets the max of this FacetStatistics.


        :param max: The max of this FacetStatistics.
        :type: float
        """
        self._max = max

    @property
    def mean(self):
        """
        Gets the mean of this FacetStatistics.


        :return: The mean of this FacetStatistics.
        :rtype: float
        """
        return self._mean

    @mean.setter
    def mean(self, mean):
        """
        Sets the mean of this FacetStatistics.


        :param mean: The mean of this FacetStatistics.
        :type: float
        """
        self._mean = mean

    @property
    def std_deviation(self):
        """
        Gets the std_deviation of this FacetStatistics.


        :return: The std_deviation of this FacetStatistics.
        :rtype: float
        """
        return self._std_deviation

    @std_deviation.setter
    def std_deviation(self, std_deviation):
        """
        Sets the std_deviation of this FacetStatistics.


        :param std_deviation: The std_deviation of this FacetStatistics.
        :type: float
        """
        self._std_deviation = std_deviation

    @property
    def date_min(self):
        """
        Gets the date_min of this FacetStatistics.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_min of this FacetStatistics.
        :rtype: datetime
        """
        return self._date_min

    @date_min.setter
    def date_min(self, date_min):
        """
        Sets the date_min of this FacetStatistics.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_min: The date_min of this FacetStatistics.
        :type: datetime
        """
        self._date_min = date_min

    @property
    def date_max(self):
        """
        Gets the date_max of this FacetStatistics.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_max of this FacetStatistics.
        :rtype: datetime
        """
        return self._date_max

    @date_max.setter
    def date_max(self, date_max):
        """
        Sets the date_max of this FacetStatistics.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_max: The date_max of this FacetStatistics.
        :type: datetime
        """
        self._date_max = date_max

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class VoiceRate(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        VoiceRate - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'currency': 'str',
            'amendment_id': 'str',
            'type': 'str',
            'effective_date': 'datetime',
            'rate': 'float',
            'duration_minimum_seconds': 'int',
            'duration_increment_seconds': 'int',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'currency': 'currency',
            'amendment_id': 'amendmentId',
            'type': 'type',
            'effective_date': 'effectiveDate',
            'rate': 'rate',
            'duration_minimum_seconds': 'durationMinimumSeconds',
            'duration_increment_seconds': 'durationIncrementSeconds',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._currency = None
        self._amendment_id = None
        self._type = None
        self._effective_date = None
        self._rate = None
        self._duration_minimum_seconds = None
        self._duration_increment_seconds = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this VoiceRate.
        The globally unique identifier for the object.

        :return: The id of this VoiceRate.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this VoiceRate.
        The globally unique identifier for the object.

        :param id: The id of this VoiceRate.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this VoiceRate.


        :return: The name of this VoiceRate.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this VoiceRate.


        :param name: The name of this VoiceRate.
        :type: str
        """
        self._name = name

    @property
    def currency(self):
        """
        Gets the currency of this VoiceRate.
        The ISO 4217 currency code of the voice rate.

        :return: The currency of this VoiceRate.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """
        Sets the currency of this VoiceRate.
        The ISO 4217 currency code of the voice rate.

        :param currency: The currency of this VoiceRate.
        :type: str
        """
        self._currency = currency

    @property
    def amendment_id(self):
        """
        Gets the amendment_id of this VoiceRate.
        The amendment Id of the voice rate.

        :return: The amendment_id of this VoiceRate.
        :rtype: str
        """
        return self._amendment_id

    @amendment_id.setter
    def amendment_id(self, amendment_id):
        """
        Sets the amendment_id of this VoiceRate.
        The amendment Id of the voice rate.

        :param amendment_id: The amendment_id of this VoiceRate.
        :type: str
        """
        self._amendment_id = amendment_id

    @property
    def type(self):
        """
        Gets the type of this VoiceRate.
        The voice rate type.

        :return: The type of this VoiceRate.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this VoiceRate.
        The voice rate type.

        :param type: The type of this VoiceRate.
        :type: str
        """
        allowed_values = ["RATE_TOLL_FREE", "RATE_TOLLED", "OUTBOUND_INTERSTATE", "OUTBOUND_INTRASTATE", "OUTBOUND_LOCAL", "EXTENDED"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type`, must be one of {0}"
                .format(allowed_values)
            )
        self._type = type

    @property
    def effective_date(self):
        """
        Gets the effective_date of this VoiceRate.
        The effective date. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The effective_date of this VoiceRate.
        :rtype: datetime
        """
        return self._effective_date

    @effective_date.setter
    def effective_date(self, effective_date):
        """
        Sets the effective_date of this VoiceRate.
        The effective date. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param effective_date: The effective_date of this VoiceRate.
        :type: datetime
        """
        self._effective_date = effective_date

    @property
    def rate(self):
        """
        Gets the rate of this VoiceRate.
        The rate.

        :return: The rate of this VoiceRate.
        :rtype: float
        """
        return self._rate

    @rate.setter
    def rate(self, rate):
        """
        Sets the rate of this VoiceRate.
        The rate.

        :param rate: The rate of this VoiceRate.
        :type: float
        """
        self._rate = rate

    @property
    def duration_minimum_seconds(self):
        """
        Gets the duration_minimum_seconds of this VoiceRate.
        The minimum duration charged in seconds.

        :return: The duration_minimum_seconds of this VoiceRate.
        :rtype: int
        """
        return self._duration_minimum_seconds

    @duration_minimum_seconds.setter
    def duration_minimum_seconds(self, duration_minimum_seconds):
        """
        Sets the duration_minimum_seconds of this VoiceRate.
        The minimum duration charged in seconds.

        :param duration_minimum_seconds: The duration_minimum_seconds of this VoiceRate.
        :type: int
        """
        self._duration_minimum_seconds = duration_minimum_seconds

    @property
    def duration_increment_seconds(self):
        """
        Gets the duration_increment_seconds of this VoiceRate.
        The billing duration increment in seconds.

        :return: The duration_increment_seconds of this VoiceRate.
        :rtype: int
        """
        return self._duration_increment_seconds

    @duration_increment_seconds.setter
    def duration_increment_seconds(self, duration_increment_seconds):
        """
        Sets the duration_increment_seconds of this VoiceRate.
        The billing duration increment in seconds.

        :param duration_increment_seconds: The duration_increment_seconds of this VoiceRate.
        :type: int
        """
        self._duration_increment_seconds = duration_increment_seconds

    @property
    def self_uri(self):
        """
        Gets the self_uri of this VoiceRate.
        The URI for this object

        :return: The self_uri of this VoiceRate.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this VoiceRate.
        The URI for this object

        :param self_uri: The self_uri of this VoiceRate.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class UserActionMetadata(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        UserActionMetadata - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'category': 'str',
            'deprecated': 'bool',
            'description': 'str',
            'published': 'bool',
            'tags': 'list[str]',
            'help_link': 'str',
            'requests': 'list[UserActionMetadataRequest]',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'category': 'category',
            'deprecated': 'deprecated',
            'description': 'description',
            'published': 'published',
            'tags': 'tags',
            'help_link': 'helpLink',
            'requests': 'requests',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._category = None
        self._deprecated = False
        self._description = None
        self._published = False
        self._tags = None
        self._help_link = None
        self._requests = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this UserActionMetadata.
        The globally unique identifier for the object.

        :return: The id of this UserActionMetadata.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this UserActionMetadata.
        The globally unique identifier for the object.

        :param id: The id of this UserActionMetadata.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this UserActionMetadata.


        :return: The name of this UserActionMetadata.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UserActionMetadata.


        :param name: The name of this UserActionMetadata.
        :type: str
        """
        self._name = name

    @property
    def category(self):
        """
        Gets the category of this UserActionMetadata.


        :return: The category of this UserActionMetadata.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this UserActionMetadata.


        :param category: The category of this UserActionMetadata.
        :type: str
        """
        self._category = category

    @property
    def deprecated(self):
        """
        Gets the deprecated of this UserActionMetadata.


        :return: The deprecated of this UserActionMetadata.
        :rtype: bool
        """
        return self._deprecated

    @deprecated.setter
    def deprecated(self, deprecated):
        """
        Sets the deprecated of this UserActionMetadata.


        :param deprecated: The deprecated of this UserActionMetadata.
        :type: bool
        """
        self._deprecated = deprecated

    @property
    def description(self):
        """
        Gets the description of this UserActionMetadata.


        :return: The description of this UserActionMetadata.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UserActionMetadata.


        :param description: The description of this UserActionMetadata.
        :type: str
        """
        self._description = description

    @property
    def published(self):
        """
        Gets the published of this UserActionMetadata.


        :return: The published of this UserActionMetadata.
        :rtype: bool
        """
        return self._published

    @published.setter
    def published(self, published):
        """
        Sets the published of this UserActionMetadata.


        :param published: The published of this UserActionMetadata.
        :type: bool
        """
        self._published = published

    @property
    def tags(self):
        """
        Gets the tags of this UserActionMetadata.


        :return: The tags of this UserActionMetadata.
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """
        Sets the tags of this UserActionMetadata.


        :param tags: The tags of this UserActionMetadata.
        :type: list[str]
        """
        self._tags = tags

    @property
    def help_link(self):
        """
        Gets the help_link of this UserActionMetadata.


        :return: The help_link of this UserActionMetadata.
        :rtype: str
        """
        return self._help_link

    @help_link.setter
    def help_link(self, help_link):
        """
        Sets the help_link of this UserActionMetadata.


        :param help_link: The help_link of this UserActionMetadata.
        :type: str
        """
        self._help_link = help_link

    @property
    def requests(self):
        """
        Gets the requests of this UserActionMetadata.


        :return: The requests of this UserActionMetadata.
        :rtype: list[UserActionMetadataRequest]
        """
        return self._requests

    @requests.setter
    def requests(self, requests):
        """
        Sets the requests of this UserActionMetadata.


        :param requests: The requests of this UserActionMetadata.
        :type: list[UserActionMetadataRequest]
        """
        self._requests = requests

    @property
    def self_uri(self):
        """
        Gets the self_uri of this UserActionMetadata.
        The URI for this object

        :return: The self_uri of this UserActionMetadata.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this UserActionMetadata.
        The URI for this object

        :param self_uri: The self_uri of this UserActionMetadata.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class MediaParticipantRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        MediaParticipantRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'wrapup': 'Wrapup',
            'state': 'str',
            'recording': 'bool',
            'muted': 'bool',
            'confined': 'bool',
            'held': 'bool',
            'wrapup_skipped': 'bool'
        }

        self.attribute_map = {
            'wrapup': 'wrapup',
            'state': 'state',
            'recording': 'recording',
            'muted': 'muted',
            'confined': 'confined',
            'held': 'held',
            'wrapup_skipped': 'wrapupSkipped'
        }

        self._wrapup = None
        self._state = None
        self._recording = False
        self._muted = False
        self._confined = False
        self._held = False
        self._wrapup_skipped = False

    @property
    def wrapup(self):
        """
        Gets the wrapup of this MediaParticipantRequest.
        Wrap-up to assign to this participant.

        :return: The wrapup of this MediaParticipantRequest.
        :rtype: Wrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this MediaParticipantRequest.
        Wrap-up to assign to this participant.

        :param wrapup: The wrapup of this MediaParticipantRequest.
        :type: Wrapup
        """
        self._wrapup = wrapup

    @property
    def state(self):
        """
        Gets the state of this MediaParticipantRequest.
        The state to update to set for this participant's communications.  Possible values are: 'connected' and 'disconnected'.

        :return: The state of this MediaParticipantRequest.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this MediaParticipantRequest.
        The state to update to set for this participant's communications.  Possible values are: 'connected' and 'disconnected'.

        :param state: The state of this MediaParticipantRequest.
        :type: str
        """
        allowed_values = ["ALERTING", "DIALING", "CONTACTING", "OFFERING", "CONNECTED", "DISCONNECTED", "TERMINATED", "CONVERTING", "UPLOADING", "TRANSMITTING", "NONE"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )
        self._state = state

    @property
    def recording(self):
        """
        Gets the recording of this MediaParticipantRequest.
        True to enable recording of this participant, otherwise false to disable recording.

        :return: The recording of this MediaParticipantRequest.
        :rtype: bool
        """
        return self._recording

    @recording.setter
    def recording(self, recording):
        """
        Sets the recording of this MediaParticipantRequest.
        True to enable recording of this participant, otherwise false to disable recording.

        :param recording: The recording of this MediaParticipantRequest.
        :type: bool
        """
        self._recording = recording

    @property
    def muted(self):
        """
        Gets the muted of this MediaParticipantRequest.
        True to mute this conversation participant.

        :return: The muted of this MediaParticipantRequest.
        :rtype: bool
        """
        return self._muted

    @muted.setter
    def muted(self, muted):
        """
        Sets the muted of this MediaParticipantRequest.
        True to mute this conversation participant.

        :param muted: The muted of this MediaParticipantRequest.
        :type: bool
        """
        self._muted = muted

    @property
    def confined(self):
        """
        Gets the confined of this MediaParticipantRequest.
        True to confine this conversation participant.  Should only be used for ad-hoc conferences

        :return: The confined of this MediaParticipantRequest.
        :rtype: bool
        """
        return self._confined

    @confined.setter
    def confined(self, confined):
        """
        Sets the confined of this MediaParticipantRequest.
        True to confine this conversation participant.  Should only be used for ad-hoc conferences

        :param confined: The confined of this MediaParticipantRequest.
        :type: bool
        """
        self._confined = confined

    @property
    def held(self):
        """
        Gets the held of this MediaParticipantRequest.
        True to hold this conversation participant.

        :return: The held of this MediaParticipantRequest.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this MediaParticipantRequest.
        True to hold this conversation participant.

        :param held: The held of this MediaParticipantRequest.
        :type: bool
        """
        self._held = held

    @property
    def wrapup_skipped(self):
        """
        Gets the wrapup_skipped of this MediaParticipantRequest.
        True to skip wrap-up for this participant.

        :return: The wrapup_skipped of this MediaParticipantRequest.
        :rtype: bool
        """
        return self._wrapup_skipped

    @wrapup_skipped.setter
    def wrapup_skipped(self, wrapup_skipped):
        """
        Sets the wrapup_skipped of this MediaParticipantRequest.
        True to skip wrap-up for this participant.

        :param wrapup_skipped: The wrapup_skipped of this MediaParticipantRequest.
        :type: bool
        """
        self._wrapup_skipped = wrapup_skipped

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

